# -*- coding: utf-8 -*-
"""
Created on Wed Oct 6th 2020

@author: rdvan, shikha

This is the model by Beretta and Kuang, with an equation for toxin and parameters are taken from literature with suggested conditions for UT Austin.
The output is 15 graphs for phage (for each combination of the 5 concentrations and 3 MOI).
"""

import scipy.integrate as spi
import matplotlib.pyplot as plt
from austin_parameters import *
#from austin_parameters2 import *

def system_water(t,y,p):
    # Define dependent variables

    X_s, X_i, P = y[0], y[1], y[2]
    # X_s = susceptible cell concentration (number/ml)
    # X_i = infected cell concentration (number/ml)
    # P = phage concentration (number/ml)
    
    mu, C, ep, Lambda, gamma, beta = p[0], p[1], p[2], p[3], p[4], p[5] 
    # mu  = bacterial growthrate 1/h
    # C = carrying capacity 1/ml
    # ep = bacterial contact rate constant ml/h
    # Lambda = bacterial lysis death rate 1/h
    # gamma = phage deathrate 1/h
    # beta = virus replication factor
    
    
    # total bacterial concentration
    X_t = X_s +X_i                          
    
    # Define ODEs
    if X_s<0:
        X_s = 0        
    dX_s = mu*X_s*(1 -X_t/C) - ep*X_s*P      
    dX_i = ep*X_s*P - Lambda*X_i
    dP = -ep*X_s*P - gamma*P + beta*Lambda*X_i
    dLys = Lambda*X_i
        
    return [dX_s, dX_i, dP,dLys]

    
a = 1
param[3] = austin_data[a][1]
param[5] = austin_data[a][2]

for b in range(len(sus_range2)):
    X_s0 = sus_range2[b] 
    for c in range(len(MOI2)):
        P0 = sus_range2[b]*MOI2[c]

        sol = spi.solve_ivp(lambda t, y: system_water(t,y,param), [t0,tend],[X_s0, X_i0, P0,0], method='RK45', t_eval=tspan)
    
        # Plot the concentrations in time
        plt.clf()
        plt.figure(1)
                    
        plt.subplot(221)
        plt.plot(sol.t, sol.y[0], '-b')
        plt.xlabel('time (hours)')
        plt.ylabel('X_s (number/ml)')
        
        plt.subplot(222)
        plt.plot(sol.t, sol.y[1], '-b')
        plt.xlabel('time (hours)')
        plt.ylabel('X_i (number/ml)')
        
        plt.subplot(223)
        plt.plot(sol.t, sol.y[2], '-b')
        plt.xlabel('time (hours)')
        plt.ylabel('P (number/ml)')
        
        plt.subplot(224)
        plt.plot(sol.t, sol.y[3], '-b')
        plt.xlabel('time (hours)')
        plt.ylabel('X_lysed (number/ml)')
        
        plt.subplots_adjust(right=1.7, wspace=0.4, hspace=0.4)
        plt.suptitle("Phage genome is {}, the cell density is {}, MOI is {}".format(austin_data[a][0], sus_name2[b], MOI2[c]),x=0.9)
        plt.savefig("genome=" + str(austin_data[a][0]) + "_density=" + str(sus2[b]) +"_MOI="+ str(MOI2[c])+".png", bbox_inches='tight')
        plt.show()
       